@@ -257,6 +257,7 @@ class Input(Widget, can_focus=True):
         id: str | None = None,
         classes: str | None = None,
         disabled: bool = False,
+        tooltip: RenderableType | None = None,
     ) -> None:
         """Initialise the `Input` widget.
 
@@ -279,6 +280,7 @@ class Input(Widget, can_focus=True):
             id: Optional ID for the widget.
             classes: Optional initial classes for the widget.
             disabled: Whether the input is disabled or not.
+            tooltip: Optional tooltip.
         """
         super().__init__(name=name, id=id, classes=classes, disabled=disabled)
 
@@ -335,6 +337,8 @@ class Input(Widget, can_focus=True):
 
         if value is not None:
             self.value = value
+        if tooltip is not None:
+            self.tooltip = tooltip
 
     def _position_to_cell(self, position: int) -> int:
         """Convert an index within the value to cell position."""
@@ -519,6 +523,7 @@ class Input(Widget, can_focus=True):
         if self.cursor_blink:
             self._blink_timer.resume()
         self.app.cursor_position = self.cursor_screen_offset
+        self._suggestion = ""
 
     async def _on_key(self, event: events.Key) -> None:
         self._cursor_visible = True
